==> sm-echarts-1.0.3.tgz: package/es/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
var _excluded = ["series"],
    _excluded2 = ["xAxis", "yAxis"],
    _excluded3 = ["xAxis", "yAxis"];
import "core-js/modules/es.array.for-each.js";
import "core-js/modules/es.array.is-array.js";
import "core-js/modules/es.array.map.js";
import "core-js/modules/es.array.from.js";
import "core-js/modules/es.string.iterator.js";
import "core-js/modules/web.dom-collections.for-each.js";
import "core-js/modules/es.array.filter.js";
import "core-js/modules/es.object.assign.js";
import "core-js/modules/es.array.some.js";
import "core-js/modules/es.array.includes.js";
import "core-js/modules/es.array.concat.js";
import React from 'react';
import * as echarts from 'echarts';
import classNames from 'classnames';
import { EventUtil } from './utils';
import './index.less';
export { default as ColorUtil } from './utils/color-util'; // lodash 递归合并

var merge = require('lodash/object/merge'); // lodash 深拷贝


var deepClone = require('lodash/lang/cloneDeep'); // lodash 节流


var throttle = require('lodash/function/throttle'); // lodash 防抖


var debounce = require('lodash/function/debounce'); // 图表类型


var ResizeEvent = 'resize.chart';

var SmECharts = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(SmECharts, _React$Component);

  /**
   * 可以替换 echarts 版本
   */

  /**
   * 默认配置项
   */
  function SmECharts(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;
    _this.setChartOption = debounce(function () {
      var _this$chartInstance;

      var _this$props = _this.props,
          notMerge = _this$props.notMerge,
          lazyUpdate = _this$props.lazyUpdate,
          debug = _this$props.debug;

      var option = _this.getMergedOption();

      debug && console.info('setOption', option);
      (_this$chartInstance = _this.chartInstance) === null || _this$chartInstance === void 0 ? void 0 : _this$chartInstance.setOption(option, notMerge, lazyUpdate);
    }, 100);
    _this.handleWindowResize = throttle(function () {
      var _this$chartInstance2, _this$chartInstance3;

      (_this$chartInstance2 = _this.chartInstance) === null || _this$chartInstance2 === void 0 ? void 0 : _this$chartInstance2.clear();
      (_this$chartInstance3 = _this.chartInstance) === null || _this$chartInstance3 === void 0 ? void 0 : _this$chartInstance3.resize();

      _this.setChartOption();
    }, 67);
    return _this;
  }
  /**
   * 将 option 中特定项转成数组
   * @param option
   */


  var _proto = SmECharts.prototype;

  _proto.transOptionItem2Array = function transOptionItem2Array(option) {
    var newOption = deepClone(option);
    ['legend', 'grid', 'xAxis', 'yAxis', 'geo', 'series', 'tooltip'].forEach(function (key) {
      if (newOption !== null && newOption !== void 0 && newOption[key] && !Array.isArray(newOption[key])) {
        newOption[key] = [newOption[key]];
      }
    });
    return newOption;
  };

  _proto.getMergedSeries = function getMergedSeries() {
    var _this$props2 = this.props,
        _this$props2$option = _this$props2.option,
        option = _this$props2$option === void 0 ? {} : _this$props2$option,
        series = _this$props2.series,
        multi = _this$props2.multi,
        data = _this$props2.data,
        type = _this$props2.type;
    var dataArr = Array.isArray(type) || multi ? data : [data];
    var types = Array.isArray(type) ? type : [type];

    if (multi && types.length === 1 && dataArr.length > 1) {
      types = Array.from({
        length: dataArr.length
      }).map(function () {
        return types[0];
      });
    } // @ts-ignore


    var mergedSeries = types.map(function (type, i) {
      return {
        type: type,
        data: dataArr[i] || []
      };
    });
    [option === null || option === void 0 ? void 0 : option.series, series].filter(Boolean).forEach(function (series) {
      if (Array.isArray(series)) {
        mergedSeries = merge([], mergedSeries, series);
      } else if (typeof series === 'object') {
        // @ts-ignore
        mergedSeries = mergedSeries.map(function (item) {
          return Object.assign({}, item, series);
        });
      }
    });
    return mergedSeries;
  };

  _proto.getMergedOption = function getMergedOption() {
    var _this$props3 = this.props,
        _this$props3$option = _this$props3.option,
        option = _this$props3$option === void 0 ? {} : _this$props3$option,
        type = _this$props3.type,
        grid = _this$props3.grid,
        legend = _this$props3.legend,
        geo = _this$props3.geo,
        xAxis = _this$props3.xAxis,
        yAxis = _this$props3.yAxis,
        rotateAxis = _this$props3.rotateAxis,
        tooltip = _this$props3.tooltip,
        category = _this$props3.category;

    var _ = option.series,
        others = _objectWithoutPropertiesLoose(option, _excluded);

    var mergedSeries = this.getMergedSeries();
    var types = Array.isArray(type) ? type : [type];
    var defaultOption = deepClone(SmECharts.defaultOption); // 需要坐标轴的图表
    // line,bar,scatter,effectScatter,pictorialBar(象形图),
    // boxplot(箱形图),candlestick(k线图),heatmap(热力图),custom

    if (types.some(function (type) {
      return ['line', 'bar', 'scatter', 'effectScatter', 'pictorialBar', 'boxplot', 'candlestick', 'heatmap', 'custom'].includes(type);
    })) {
      var _ref2, _ref3, _ref4;

      var _SmECharts$defaultAxi = SmECharts.defaultAxis,
          _SmECharts$defaultAxi2 = _SmECharts$defaultAxi.xAxis,
          _xAxis = _SmECharts$defaultAxi2 === void 0 ? {} : _SmECharts$defaultAxi2,
          _SmECharts$defaultAxi3 = _SmECharts$defaultAxi.yAxis,
          _yAxis = _SmECharts$defaultAxi3 === void 0 ? {} : _SmECharts$defaultAxi3,
          defaultAxis = _objectWithoutPropertiesLoose(_SmECharts$defaultAxi, _excluded2);

      var _defaultOption = defaultOption,
          _defaultOption$xAxis = _defaultOption.xAxis,
          x = _defaultOption$xAxis === void 0 ? {} : _defaultOption$xAxis,
          _defaultOption$yAxis = _defaultOption.yAxis,
          y = _defaultOption$yAxis === void 0 ? {} : _defaultOption$yAxis,
          _option = _objectWithoutPropertiesLoose(_defaultOption, _excluded3);

      var _ref = rotateAxis ? ['yAxis', 'xAxis'] : ['xAxis', 'yAxis'],
          xa = _ref[0],
          ya = _ref[1]; // 合并坐标轴相关默认配置


      defaultOption = merge.apply(void 0, [{}].concat([(_ref2 = {}, _ref2[xa] = _xAxis, _ref2[ya] = _yAxis, _ref2), (_ref3 = {}, _ref3[xa] = x, _ref3[ya] = y, _ref3), defaultAxis, _option, Array.isArray(category) && (_ref4 = {}, _ref4[xa] = {
        data: category
      }, _ref4)].filter(Boolean)));
    }

    return merge.apply(void 0, [{}].concat([defaultOption, others, {
      legend: legend,
      grid: grid,
      xAxis: xAxis,
      yAxis: yAxis,
      geo: geo,
      tooltip: tooltip
    }, {
      series: mergedSeries
    }].map(this.transOptionItem2Array)));
  };

  _proto.componentDidMount = function componentDidMount() {
    // @ts-ignore
    this.chartInstance = echarts.init(this.$root);
    this.setChartOption(); // 监听resize

    EventUtil.addEventListener(ResizeEvent, this.handleWindowResize);
  };

  _proto.componentDidUpdate = function componentDidUpdate() {
    this.setChartOption();
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    var _this$chartInstance4;

    // 移除监听resize
    EventUtil.removeEventListener(ResizeEvent, this.handleWindowResize); // 销毁

    (_this$chartInstance4 = this.chartInstance) === null || _this$chartInstance4 === void 0 ? void 0 : _this$chartInstance4.dispose();
  };

  _proto.render = function render() {
    var _this2 = this;

    var _this$props4 = this.props,
        className = _this$props4.className,
        style = _this$props4.style;
    return /*#__PURE__*/React.createElement("div", {
      ref: function ref(el) {
        return _this2.$root = el;
      },
      className: classNames('sm-echarts', className),
      style: style
    });
  };

  return SmECharts;
}(React.Component);

SmECharts.echarts = echarts;
SmECharts.defaultProps = {
  type: 'line',
  notMerge: false,
  lazyUpdate: false
};
SmECharts.defaultOption = {};
SmECharts.defaultAxis = {
  // 坐标系
  grid: {
    show: true,
    borderColor: 'transparent',
    borderWidth: 0
  },
  // x轴
  xAxis: {
    show: true,
    type: 'category'
  },
  // y轴
  yAxis: {
    show: true,
    type: 'value'
  }
};
export { SmECharts as default };

==> sm-echarts-1.0.5.tgz: package/es/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
var _excluded = ["series"],
    _excluded2 = ["xAxis", "yAxis"],
    _excluded3 = ["xAxis", "yAxis"];
import "core-js/modules/es.array.join.js";
import "core-js/modules/es.array.filter.js";
import "core-js/modules/es.array.for-each.js";
import "core-js/modules/web.dom-collections.for-each.js";
import "core-js/modules/es.object.keys.js";
import "core-js/modules/es.array.is-array.js";
import "core-js/modules/es.array.every.js";
import "core-js/modules/es.array.map.js";
import "core-js/modules/es.array.from.js";
import "core-js/modules/es.string.iterator.js";
import "core-js/modules/es.object.assign.js";
import "core-js/modules/es.array.some.js";
import "core-js/modules/es.array.includes.js";
import "core-js/modules/es.array.concat.js";
import React from 'react';
import * as echarts from 'echarts';
import { EventUtil } from './utils';
import './index.less';
import TypeUtil from './utils/type-util';
export { default as ColorUtil } from './utils/color-util'; // lodash 递归合并

var merge = require('lodash/object/merge'); // lodash 深拷贝


var deepClone = require('lodash/lang/cloneDeep'); // lodash 节流


var throttle = require('lodash/function/throttle'); // lodash 防抖


var debounce = require('lodash/function/debounce');

var classNames = function classNames() {
  for (var _len = arguments.length, names = new Array(_len), _key = 0; _key < _len; _key++) {
    names[_key] = arguments[_key];
  }

  return names.filter(Boolean).join(' ');
}; // 图表类型


var ResizeEvent = 'resize.chart';

var SmECharts = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(SmECharts, _React$Component);

  /**
   * 可以替换 echarts 版本
   */

  /**
   * 默认配置项
   */
  function SmECharts(_props) {
    var _this;

    _this = _React$Component.call(this, _props) || this;
    _this.setChartOption = debounce(function () {
      var _this$echartsInstance;

      var _this$props = _this.props,
          notMerge = _this$props.notMerge,
          lazyUpdate = _this$props.lazyUpdate,
          debug = _this$props.debug;

      var option = _this.getMergedOption();

      debug && console.info('setOption', option);
      (_this$echartsInstance = _this.echartsInstance) === null || _this$echartsInstance === void 0 ? void 0 : _this$echartsInstance.setOption(option, notMerge, lazyUpdate);
    }, 100);
    _this.handleWindowResize = throttle(function () {
      var _this$echartsInstance2, _this$echartsInstance3;

      (_this$echartsInstance2 = _this.echartsInstance) === null || _this$echartsInstance2 === void 0 ? void 0 : _this$echartsInstance2.clear();
      (_this$echartsInstance3 = _this.echartsInstance) === null || _this$echartsInstance3 === void 0 ? void 0 : _this$echartsInstance3.resize();

      _this.setChartOption();
    }, 67);

    _this.unbindEvents = function (props) {
      Object.keys(props.onEvents || {}).forEach(function (eventName) {
        var _this$echartsInstance4;

        return (_this$echartsInstance4 = _this.echartsInstance) === null || _this$echartsInstance4 === void 0 ? void 0 : _this$echartsInstance4.off(eventName);
      });
    };

    _this.bindEvens = function () {
      var events = _this.props.onEvents || {};
      var isDebug = _this.props.debug;

      var bindEvent = function bindEvent(eventName, handler) {
        if (typeof handler === 'function') {
          var _this$echartsInstance5;

          isDebug && console.info('绑定事件', eventName);
          (_this$echartsInstance5 = _this.echartsInstance) === null || _this$echartsInstance5 === void 0 ? void 0 : _this$echartsInstance5.on(eventName, handler);
        } else if (Array.isArray(handler) && handler.length === 2) {
          var _this$echartsInstance6;

          var query = handler[0],
              eventHandler = handler[1];
          isDebug && console.info('绑定事件', eventName, query);
          (_this$echartsInstance6 = _this.echartsInstance) === null || _this$echartsInstance6 === void 0 ? void 0 : _this$echartsInstance6.on(eventName, query, eventHandler);
        }
      };

      Object.keys(events).forEach(function (eventName) {
        var handler = events[eventName];

        if (Array.isArray(handler)) {
          if (handler.length === 2 && handler.every(function (item) {
            return !Array.isArray(item);
          }) && (TypeUtil.isPlainObject(handler[0]) || TypeUtil.isString(handler[0])) && typeof handler[1] === 'function') {
            // @ts-ignore
            bindEvent(eventName, handler);
          } else {
            handler.forEach(function (eventHandler) {
              return bindEvent(eventName, eventHandler);
            });
          }
        } else if (typeof handler === 'function') {
          bindEvent(eventName, handler);
        }
      });
    };

    return _this;
  }
  /**
   * 将 option 中特定项转成数组
   * @param option
   */


  var _proto = SmECharts.prototype;

  _proto.transOptionItem2Array = function transOptionItem2Array(option) {
    var newOption = deepClone(option);
    ['legend', 'grid', 'xAxis', 'yAxis', 'geo', 'series', 'tooltip'].forEach(function (key) {
      if (newOption !== null && newOption !== void 0 && newOption[key] && !Array.isArray(newOption[key])) {
        newOption[key] = [newOption[key]];
      }
    });
    return newOption;
  };

  _proto.getMergedSeries = function getMergedSeries() {
    var _this$props2 = this.props,
        _this$props2$option = _this$props2.option,
        option = _this$props2$option === void 0 ? {} : _this$props2$option,
        series = _this$props2.series,
        multi = _this$props2.multi,
        data = _this$props2.data,
        type = _this$props2.type;
    var dataArr = Array.isArray(type) || multi ? data : [data];
    var types = Array.isArray(type) ? type : [type];

    if (multi && types.length === 1 && dataArr.length > 1) {
      types = Array.from({
        length: dataArr.length
      }).map(function () {
        return types[0];
      });
    } // @ts-ignore


    var mergedSeries = types.map(function (type, i) {
      return {
        type: type,
        data: dataArr[i] || []
      };
    });
    [option === null || option === void 0 ? void 0 : option.series, series].filter(Boolean).forEach(function (series) {
      if (Array.isArray(series)) {
        mergedSeries = merge([], mergedSeries, series);
      } else if (typeof series === 'object') {
        // @ts-ignore
        mergedSeries = mergedSeries.map(function (item) {
          return Object.assign({}, item, series);
        });
      }
    });
    return mergedSeries;
  };

  _proto.getMergedOption = function getMergedOption() {
    var _this$props3 = this.props,
        _this$props3$option = _this$props3.option,
        option = _this$props3$option === void 0 ? {} : _this$props3$option,
        type = _this$props3.type,
        grid = _this$props3.grid,
        legend = _this$props3.legend,
        geo = _this$props3.geo,
        xAxis = _this$props3.xAxis,
        yAxis = _this$props3.yAxis,
        rotateAxis = _this$props3.rotateAxis,
        tooltip = _this$props3.tooltip,
        category = _this$props3.category;

    var _ = option.series,
        others = _objectWithoutPropertiesLoose(option, _excluded);

    var mergedSeries = this.getMergedSeries();
    var types = Array.isArray(type) ? type : [type];
    var defaultOption = deepClone(SmECharts.defaultOption); // 需要坐标轴的图表
    // line,bar,scatter,effectScatter,pictorialBar(象形图),
    // boxplot(箱形图),candlestick(k线图),heatmap(热力图),custom

    if (types.some(function (type) {
      return ['line', 'bar', 'scatter', 'effectScatter', 'pictorialBar', 'boxplot', 'candlestick', 'heatmap', 'custom'].includes(type);
    })) {
      var _ref2, _ref3, _ref4;

      var _SmECharts$defaultAxi = SmECharts.defaultAxis,
          _SmECharts$defaultAxi2 = _SmECharts$defaultAxi.xAxis,
          _xAxis = _SmECharts$defaultAxi2 === void 0 ? {} : _SmECharts$defaultAxi2,
          _SmECharts$defaultAxi3 = _SmECharts$defaultAxi.yAxis,
          _yAxis = _SmECharts$defaultAxi3 === void 0 ? {} : _SmECharts$defaultAxi3,
          defaultAxis = _objectWithoutPropertiesLoose(_SmECharts$defaultAxi, _excluded2);

      var _defaultOption = defaultOption,
          _defaultOption$xAxis = _defaultOption.xAxis,
          x = _defaultOption$xAxis === void 0 ? {} : _defaultOption$xAxis,
          _defaultOption$yAxis = _defaultOption.yAxis,
          y = _defaultOption$yAxis === void 0 ? {} : _defaultOption$yAxis,
          _option = _objectWithoutPropertiesLoose(_defaultOption, _excluded3);

      var _ref = rotateAxis ? ['yAxis', 'xAxis'] : ['xAxis', 'yAxis'],
          xa = _ref[0],
          ya = _ref[1]; // 合并坐标轴相关默认配置


      defaultOption = merge.apply(void 0, [{}].concat([(_ref2 = {}, _ref2[xa] = _xAxis, _ref2[ya] = _yAxis, _ref2), (_ref3 = {}, _ref3[xa] = x, _ref3[ya] = y, _ref3), defaultAxis, _option, Array.isArray(category) && (_ref4 = {}, _ref4[xa] = {
        data: category
      }, _ref4)].filter(Boolean)));
    }

    return merge.apply(void 0, [{}].concat([defaultOption, others, {
      legend: legend,
      grid: grid,
      xAxis: xAxis,
      yAxis: yAxis,
      geo: geo,
      tooltip: tooltip
    }, {
      series: mergedSeries
    }].map(this.transOptionItem2Array)));
  };

  _proto.componentDidMount = function componentDidMount() {
    // @ts-ignore
    this.echartsInstance = SmECharts.echarts.init(this.$root);
    this.setChartOption();
    this.bindEvens(); // 监听resize

    EventUtil.addEventListener(ResizeEvent, this.handleWindowResize);
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    this.setChartOption();
    this.unbindEvents(prevProps);
    this.bindEvens();
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    var _this$echartsInstance7;

    // 移除监听resize
    EventUtil.removeEventListener(ResizeEvent, this.handleWindowResize);
    this.unbindEvents(this.props); // 销毁

    (_this$echartsInstance7 = this.echartsInstance) === null || _this$echartsInstance7 === void 0 ? void 0 : _this$echartsInstance7.dispose();
  };

  _proto.render = function render() {
    var _this2 = this;

    var _this$props4 = this.props,
        className = _this$props4.className,
        style = _this$props4.style;
    return /*#__PURE__*/React.createElement("div", {
      ref: function ref(el) {
        return _this2.$root = el;
      },
      className: classNames('sm-echarts', className),
      style: style
    });
  };

  return SmECharts;
}(React.Component);

SmECharts.echarts = echarts;
SmECharts.defaultProps = {
  type: 'line',
  notMerge: false,
  lazyUpdate: false
};
SmECharts.defaultOption = {};
SmECharts.defaultAxis = {
  // 坐标系
  grid: {
    show: true,
    borderColor: 'transparent',
    borderWidth: 0
  },
  // x轴
  xAxis: {
    show: true,
    type: 'category'
  },
  // y轴
  yAxis: {
    show: true,
    type: 'value'
  }
};
export { SmECharts as default };
